@@ -16,6 +16,7 @@ from mnemonic import Mnemonic
 from ..helpers import is_testnet, generate_mnemonic
 from ..key import Key
 from ..wallet_manager import purposes
+from ..specter_error import handle_exception
 
 rand = random.randint(0, 1e32)  # to force style refresh
 
@@ -124,22 +125,32 @@ def new_device():
                 device = app.specter.device_manager.add_device(
                     name=device_name, device_type=device_type, keys=[]
                 )
-                device.setup_device(file_password, app.specter.wallet_manager)
-                device.add_hot_wallet_keys(
-                    mnemonic,
-                    passphrase,
-                    paths,
-                    file_password,
-                    app.specter.wallet_manager,
-                    is_testnet(app.specter.chain),
-                    keys_range=[range_start, range_end],
-                    keys_purposes=keys_purposes,
-                )
-                flash("{} was added successfully!".format(device_name))
-                return redirect(
-                    url_for("devices_endpoint.device", device_alias=device.alias)
-                    + "?newdevice=true"
-                )
+                try:
+                    device.setup_device(file_password, app.specter.wallet_manager)
+                    device.add_hot_wallet_keys(
+                        mnemonic,
+                        passphrase,
+                        paths,
+                        file_password,
+                        app.specter.wallet_manager,
+                        is_testnet(app.specter.chain),
+                        keys_range=[range_start, range_end],
+                        keys_purposes=keys_purposes,
+                    )
+                    flash("{} was added successfully!".format(device_name))
+                    return redirect(
+                        url_for("devices_endpoint.device", device_alias=device.alias)
+                        + "?newdevice=true"
+                    )
+                except Exception as e:
+                    handle_exception(e)
+                    flash(f"Failed to setup hot wallet. Error: {e}", "error")
+                    app.specter.device_manager.remove_device(
+                        device,
+                        app.specter.wallet_manager,
+                        bitcoin_datadir=app.specter.bitcoin_datadir,
+                        chain=app.specter.chain,
+                    )
             else:
                 flash(err, "error")
     return render_template(
@@ -209,19 +220,29 @@ def new_device_manual():
                 device = app.specter.device_manager.add_device(
                     name=device_name, device_type=device_type, keys=[]
                 )
-                device.setup_device(file_password, app.specter.wallet_manager)
-                device.add_hot_wallet_keys(
-                    mnemonic,
-                    passphrase,
-                    paths,
-                    file_password,
-                    app.specter.wallet_manager,
-                    is_testnet(app.specter.chain),
-                    keys_range=[range_start, range_end],
-                )
-                return redirect(
-                    url_for("devices_endpoint.device", device_alias=device.alias)
-                )
+                try:
+                    device.setup_device(file_password, app.specter.wallet_manager)
+                    device.add_hot_wallet_keys(
+                        mnemonic,
+                        passphrase,
+                        paths,
+                        file_password,
+                        app.specter.wallet_manager,
+                        is_testnet(app.specter.chain),
+                        keys_range=[range_start, range_end],
+                    )
+                    return redirect(
+                        url_for("devices_endpoint.device", device_alias=device.alias)
+                    )
+                except Exception as e:
+                    handle_exception(e)
+                    flash(f"Failed to setup hot wallet. Error: {e}", "error")
+                    app.specter.device_manager.remove_device(
+                        device,
+                        app.specter.wallet_manager,
+                        bitcoin_datadir=app.specter.bitcoin_datadir,
+                        chain=app.specter.chain,
+                    )
         elif action == "generatemnemonic":
             strength = int(request.form["strength"])
             mnemonic = generate_mnemonic(strength=strength)
@@ -258,7 +279,7 @@ def device(device_alias):
         action = request.form["action"]
         if action == "forget":
             if len(wallets) != 0:
-                err = "Device could not be removed since it is used in wallets: {}.\nYou must delete those wallets before you can remove this device.".format(
+                err = "Device could not be removed since it is used in wallets: {}.<br>You must delete those wallets before you can remove this device.<br>You can delete a wallet from its Settings -> Advanced page.".format(
                     [wallet.name for wallet in wallets]
                 )
             else:
@@ -270,8 +291,14 @@ def device(device_alias):
                 )
                 return redirect("")
         elif action == "delete_key":
-            key = request.form["key"]
-            device.remove_key(Key.from_json({"original": key}))
+            key = Key.from_json({"original": request.form["key"]})
+            wallets_with_key = [w for w in wallets if key in w.keys]
+            if len(wallets_with_key) != 0:
+                err = "Key could not be removed since it is used in wallets: {}.<br>You must delete those wallets before you can remove this key.<br>You can delete a wallet from its Settings -> Advanced page.".format(
+                    ", ".join([wallet.name for wallet in wallets_with_key])
+                )
+            else:
+                device.remove_key(key)
         elif action == "rename":
             device_name = request.form["newtitle"]
             if not device_name:
@@ -286,7 +313,7 @@ def device(device_alias):
             strength = 128
             mnemonic = generate_mnemonic(strength=strength)
             return render_template(
-                "device/new_device_manual.jinja",
+                "device/new_device.jinja",
                 mnemonic=mnemonic,
                 strength=strength,
                 existing_device=device,
